/**
 * Reports a diagnostic. Defined in the core compiler.
 * @beta
 */
export declare const reportDiagnostic: <C extends "no-apiVersion" | "no-route" | "general-warning" | "general-error" | "invalid-dotnet-sdk-dependency" | "no-root-client" | "unsupported-auth" | "client-namespace-conflict" | "unsupported-endpoint-url" | "unsupported-sdk-type" | "unsupported-default-value-type" | "unsupported-cookie-parameter", M extends keyof {
    "no-apiVersion": {
        readonly default: import("@typespec/compiler").CallableMessage<["service"]>;
    };
    "no-route": {
        readonly default: import("@typespec/compiler").CallableMessage<["service"]>;
    };
    "general-warning": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "general-error": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "invalid-dotnet-sdk-dependency": {
        readonly default: import("@typespec/compiler").CallableMessage<[]>;
        readonly missing: import("@typespec/compiler").CallableMessage<["dotnetMajorVersion", "downloadUrl"]>;
        readonly invalidVersion: import("@typespec/compiler").CallableMessage<["installedVersion", "dotnetMajorVersion", "downloadUrl"]>;
    };
    "no-root-client": {
        readonly default: "Cannot generate CSharp SDK since no public root client is defined in typespec file.";
    };
    "unsupported-auth": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "client-namespace-conflict": {
        readonly default: import("@typespec/compiler").CallableMessage<["clientNamespace", "clientName"]>;
    };
    "unsupported-endpoint-url": {
        readonly default: import("@typespec/compiler").CallableMessage<["endpoint"]>;
    };
    "unsupported-sdk-type": {
        readonly default: import("@typespec/compiler").CallableMessage<["sdkType"]>;
    };
    "unsupported-default-value-type": {
        readonly default: import("@typespec/compiler").CallableMessage<["valueType"]>;
    };
    "unsupported-cookie-parameter": {
        readonly default: import("@typespec/compiler").CallableMessage<["parameterName", "path"]>;
    };
}[C]>(program: import("@typespec/compiler").Program, diag: import("@typespec/compiler").DiagnosticReport<{
    "no-apiVersion": {
        readonly default: import("@typespec/compiler").CallableMessage<["service"]>;
    };
    "no-route": {
        readonly default: import("@typespec/compiler").CallableMessage<["service"]>;
    };
    "general-warning": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "general-error": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "invalid-dotnet-sdk-dependency": {
        readonly default: import("@typespec/compiler").CallableMessage<[]>;
        readonly missing: import("@typespec/compiler").CallableMessage<["dotnetMajorVersion", "downloadUrl"]>;
        readonly invalidVersion: import("@typespec/compiler").CallableMessage<["installedVersion", "dotnetMajorVersion", "downloadUrl"]>;
    };
    "no-root-client": {
        readonly default: "Cannot generate CSharp SDK since no public root client is defined in typespec file.";
    };
    "unsupported-auth": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "client-namespace-conflict": {
        readonly default: import("@typespec/compiler").CallableMessage<["clientNamespace", "clientName"]>;
    };
    "unsupported-endpoint-url": {
        readonly default: import("@typespec/compiler").CallableMessage<["endpoint"]>;
    };
    "unsupported-sdk-type": {
        readonly default: import("@typespec/compiler").CallableMessage<["sdkType"]>;
    };
    "unsupported-default-value-type": {
        readonly default: import("@typespec/compiler").CallableMessage<["valueType"]>;
    };
    "unsupported-cookie-parameter": {
        readonly default: import("@typespec/compiler").CallableMessage<["parameterName", "path"]>;
    };
}, C, M>) => void;
/**
 * Creates a diagnostic. Defined in the core compiler.
 * @beta
 */
export declare const createDiagnostic: <C extends "no-apiVersion" | "no-route" | "general-warning" | "general-error" | "invalid-dotnet-sdk-dependency" | "no-root-client" | "unsupported-auth" | "client-namespace-conflict" | "unsupported-endpoint-url" | "unsupported-sdk-type" | "unsupported-default-value-type" | "unsupported-cookie-parameter", M extends keyof {
    "no-apiVersion": {
        readonly default: import("@typespec/compiler").CallableMessage<["service"]>;
    };
    "no-route": {
        readonly default: import("@typespec/compiler").CallableMessage<["service"]>;
    };
    "general-warning": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "general-error": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "invalid-dotnet-sdk-dependency": {
        readonly default: import("@typespec/compiler").CallableMessage<[]>;
        readonly missing: import("@typespec/compiler").CallableMessage<["dotnetMajorVersion", "downloadUrl"]>;
        readonly invalidVersion: import("@typespec/compiler").CallableMessage<["installedVersion", "dotnetMajorVersion", "downloadUrl"]>;
    };
    "no-root-client": {
        readonly default: "Cannot generate CSharp SDK since no public root client is defined in typespec file.";
    };
    "unsupported-auth": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "client-namespace-conflict": {
        readonly default: import("@typespec/compiler").CallableMessage<["clientNamespace", "clientName"]>;
    };
    "unsupported-endpoint-url": {
        readonly default: import("@typespec/compiler").CallableMessage<["endpoint"]>;
    };
    "unsupported-sdk-type": {
        readonly default: import("@typespec/compiler").CallableMessage<["sdkType"]>;
    };
    "unsupported-default-value-type": {
        readonly default: import("@typespec/compiler").CallableMessage<["valueType"]>;
    };
    "unsupported-cookie-parameter": {
        readonly default: import("@typespec/compiler").CallableMessage<["parameterName", "path"]>;
    };
}[C]>(diag: import("@typespec/compiler").DiagnosticReport<{
    "no-apiVersion": {
        readonly default: import("@typespec/compiler").CallableMessage<["service"]>;
    };
    "no-route": {
        readonly default: import("@typespec/compiler").CallableMessage<["service"]>;
    };
    "general-warning": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "general-error": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "invalid-dotnet-sdk-dependency": {
        readonly default: import("@typespec/compiler").CallableMessage<[]>;
        readonly missing: import("@typespec/compiler").CallableMessage<["dotnetMajorVersion", "downloadUrl"]>;
        readonly invalidVersion: import("@typespec/compiler").CallableMessage<["installedVersion", "dotnetMajorVersion", "downloadUrl"]>;
    };
    "no-root-client": {
        readonly default: "Cannot generate CSharp SDK since no public root client is defined in typespec file.";
    };
    "unsupported-auth": {
        readonly default: import("@typespec/compiler").CallableMessage<["message"]>;
    };
    "client-namespace-conflict": {
        readonly default: import("@typespec/compiler").CallableMessage<["clientNamespace", "clientName"]>;
    };
    "unsupported-endpoint-url": {
        readonly default: import("@typespec/compiler").CallableMessage<["endpoint"]>;
    };
    "unsupported-sdk-type": {
        readonly default: import("@typespec/compiler").CallableMessage<["sdkType"]>;
    };
    "unsupported-default-value-type": {
        readonly default: import("@typespec/compiler").CallableMessage<["valueType"]>;
    };
    "unsupported-cookie-parameter": {
        readonly default: import("@typespec/compiler").CallableMessage<["parameterName", "path"]>;
    };
}, C, M>) => import("@typespec/compiler").Diagnostic;
/**
 * Gets a tracer. Defined in the core compiler.
 * @beta
 */
export declare const getTracer: (program: import("@typespec/compiler").Program) => import("@typespec/compiler").Tracer;
//# sourceMappingURL=lib.d.ts.map